# -*- coding: utf8 -*-

from django.core.management.base import NoArgsCommand

from os import makedirs
from os.path import realpath, dirname, isdir, join as pathjoin
import re
import shutil

from attachments.models import Attachment
from pages.models import PageWeb

CHEMIN_RACINE = dirname(dirname(dirname(dirname(realpath(__file__)))))
CHEMIN_BASE = pathjoin(CHEMIN_RACINE, "archive_pages_web")
CHEMIN_PIECES_JOINTES = pathjoin(CHEMIN_BASE, "pieces_jointes")


def encodage_piece_jointe(match):
    ident = match.group(1)

    piece_jointe = Attachment.objects.get(ident_main=ident)
    nom = f"{ident}.{piece_jointe.file_type}"
    chemin_orig = pathjoin(Attachment.objects.ATTACH_PATH, "static_pages", nom)
    chemin_dest = pathjoin(CHEMIN_PIECES_JOINTES, nom)

    print(f"Enregistrement de la pièce jointe {nom}")
    shutil.copy(chemin_orig, chemin_dest)

    return f"[attach]{nom}:{piece_jointe.file_name}[/attach]"


def exporter_page(page):
    print(page.ecole.ident + "/" + page.adresse)
    if page.adresse[-1] == "/":
        chemin = CHEMIN_BASE + "/" + page.ecole.ident + "/" + page.adresse.encode("ascii") + "index.bbcode"
    else:
        chemin = CHEMIN_BASE + "/" + page.ecole.ident + "/" + page.adresse.encode("ascii") + ".bbcode"

    if not isdir(dirname(chemin)):
        makedirs(dirname(chemin))

    contenu = page.contenu.as_bbcode()

    contenu = re.sub(r"\[attach\](\w+?)\[/attach\]", encodage_piece_jointe, contenu)

    with open(chemin, "wb") as fichier:
        fichier.write((page.titre + "\n"))
        fichier.write(contenu)


class Command(NoArgsCommand):
    def handle_noargs(self, **kwargs):
        if not isdir(CHEMIN_PIECES_JOINTES):
            makedirs(CHEMIN_PIECES_JOINTES)

        print(f"Écriture des pages dans {CHEMIN_BASE}…")

        for page in PageWeb.objects.all():
            exporter_page(page)

        print(f"Exportation terminée dans {CHEMIN_BASE}.")
